% Trade Liberalization and Embedded Institutional Reform:
% Evidence from Chinese Exporters
%
% Khandelwal, Schott and Wei 
% May 2011 (main_lognormal_11.m)
%
%
% This program uses the parameters discussed in Section 6 of the main text to solve the model described in the electronic 
% appendix for the no-quota and efficient-allocation equilibria. Computing these solutions requires the following functions,
% which operationalize the algorithm described in Section A of the electronic appendix. 
%
%     1. free.m
%     2. efficient.m
%     3. solve_pi_and_cutoffs.m
%
% The program political.m uses output generated by this program to solve for the political-allocation equilibrium
% described in Section 6.3 of the main text.
%
% Conventions
%   Country 1: China
%   Country 2: US
%

%startup
clear;
clc;
workdir = 'C:\Users\pks4\Documents\My Dropbox\research\mfa\matlab4';
%workdir = '/user/user1/ak2796/mfa_matlab';
cd(workdir)
path(workdir,path);
format short

%date_now = clock;
%date_now = strcat(num2str(date_now(1)),'_',num2str(date_now(2)),'_', num2str(date_now(3)));
%diary(strcat('log_', date_now,'.log'));


%parameters
disp(' ');
params.L     = [100; 100];        %[china US]
params.W     = [1 1; 1 1];        %[china china; US US]
params.N     = 2;
params.K     = 1;
params.SIG   = 4;
params.MU    = 1; 
params.LAMDA = (params.SIG/params.MU)^(1/(1-params.SIG)) * ((params.SIG-1)/params.SIG);
params.DELTA = (params.SIG/params.MU)^(1/(params.SIG-1)) * (params.SIG/(params.SIG-1));
params.PSI   =  params.SIG^(params.SIG/(1-params.SIG)) * (params.SIG-1) / params.MU^(1/(1-params.SIG));
params.A     = [0       0            ; 0             0      ];

params.MN    = .1;                %default
params.SD    = .54                %default .54
params.Fd    = 100/5e7;           %default 
params.FCHN  = 1.15;              %default
params.FUS   = 1.15;              %default
params.F     = [params.Fd params.Fd*params.FCHN; params.Fd*params.FUS params.Fd];
params.TAU   = [1 1.80; 3.55 1];   %found by lognormal_grid.m 

params.DRAWS = 1e6;
params.restrictiveness  = .38;    %1/2.61=.38 
params.match_xshare_chn = .44;    %share of chinese firms that export in annual survey
params.match_xshare_us  = .08;
params.match_cshare     = .131;   %chinese import penetration in us
params.match_ushare     = .012;   %us import penetration in china

params.disp  = 0;

disp('Parameters: [mean, sd, fixed, tau_cu tau_uc]');
disp([params.MN params.SD params.FCHN params.FUS params.TAU(1,2) params.TAU(2,1)]);

%draws: note legacy code used in first randn command; >v7 uses different initializer
%normal draws saved for use in counterfactual later
randn('state',1);                                   
params.norm1 = randn(params.DRAWS,1);
params.x     = lognrnd(params.MN,params.SD,params.DRAWS,1);
params.norm2 = randn(params.DRAWS,1);




%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%% FREE TRADE SOLUTION %%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%initial PC PU price index guess
disp('Solve Free Trade');
P0 = [0.08; 0.08];    
a0 = 0;

%given the guess, compute the price index P
options = optimset('Display','none','MaxIter',1000,'MaxFunEvals',20000,'TolX',1e-15,'TolFun',1e-15);
func = @(P) free(P,a0,params);
[P,fval,exitflag,output] = fsolve(func,P0,options);

%use P to compute the cutoffs and stuff we want to know
%these variables are preceded by "f" to denote they are "free" trade solutions
fexitflag = exitflag;
fP         = P;
ret        = solve_pi_and_cutoffs(fP,a0,params);
fxstar     = reshape(ret(1:end-1),params.N,params.N);
fpi        = ret(end);
fY         = params.W(:,1).*params.L.*(1+fpi);
tempa      = [0 0; 0 0];

for o=1:params.N
    for d=1:params.N
        findex       = params.x>fxstar(o,d);
        fprice       = (params.SIG/(params.SIG-1)).*((params.W(o,d)*params.TAU(o,d))./params.x(findex) + params.W(o,d)*tempa(o,d));
        fq1          = (params.SIG/(params.SIG-1))^(-params.SIG);
        fq2          = ((params.W(o,d)*params.TAU(o,d))./params.x(findex) + params.W(o,d)*tempa(o,d)).^(-params.SIG);
        fq3          = fP(d)^(params.SIG-1);
        fq4          = params.MU*fY(d);
        fquant       = fq1.*fq2.*fq3.*fq4;
        fsales       = fprice.*fquant;
        fprofit      = fquant.*(fprice - ((params.W(o,d)*params.TAU(o,d))./params.x(findex) + params.W(o,d)*tempa(o,d))) - (params.W(o,d)*params.F(o,d));
        fqshare      = fquant./sum(fquant);

        %production-export percentiles are:
        %[75th 90th 95th 99th 99.1th] = [0.2578752 0.2060196 0.1287987 0.2047524 0.1336276 0.0689265]
        %
        %tradedata-export percentiles are:
        %[75th 90th 95th 99th 99.1th] = [0.085 0.166 0.147 0.295 0.214 0.093]
        %


        for ppp=[50 75 90 95 99 99.9]
            if ppp==99.9
                sss = ['p' int2str(ppp*10) '=prctile(fsales,'       int2str(ppp) ');'];
                eval(sss);
                ttt = ['x' int2str(ppp*10) '=sum(fsales(fsales<p' int2str(ppp*10) '));'];
                eval(ttt);
                uuu = ['u' int2str(ppp*10) '=x' num2str(ppp*10) '/sum(fsales);'];
                eval(uuu);
            else
                sss = ['p' int2str(ppp) '=prctile(fsales,'       int2str(ppp) ');'];
                eval(sss);
                ttt = ['x' int2str(ppp) '=sum(fsales(fsales<p' int2str(ppp) '));'];
                eval(ttt);
                uuu = ['u' int2str(ppp) '=x' num2str(ppp) '/sum(fsales);'];
                eval(uuu);
            end                   
        end
 
        %report distributions to screen if needed
        fu(1:6,o,d) = [u75 u90-u75  u95-u90 u99-u95 u999-u99 1-u999];        
        
        %compute fit of parameters with data: first for export size dist from production data, then from export shiptment data
        p6   = [u75 u90-u75  u95-u90 u99-u95 u999-u99 1-u999]-[0.2578752 0.2060196 0.1287987 0.2047524 0.1336276 0.0689265];
        t6   = [u75 u90-u75  u95-u90 u99-u95 u999-u99 1-u999]-[0.085     0.166     0.147     0.295     0.214     0.093];
        
        pp6  = (p6./[0.2578752 0.2060196 0.1287987 0.2047524 0.1336276 0.0689265]); 
        tp6  = (p6./[0.085     0.166     0.147     0.295     0.214     0.093]    ); 
        
        spp6(o,d) = mean(pp6.^2); 
        stp6(o,d) = mean(tp6.^2);     
        
        %catch variables needed for later
        factive(o,d)    = length(params.x(findex));
        ftotquant(o,d)  = sum(fquant);
        ftotsales(o,d)  = sum(fsales);
        ftotprofit(o,d) = sum(fprofit);

        favgtfp(o,d)    = mean(params.x(findex));
        fwavgtfp(o,d)   = sum(fqshare.*params.x(findex));
        
        if o==1 & d==2
            params.findex12  = findex;
            params.fquant12  = fquant;
            params.fqshare12 = fqshare;
        end
        
        clear findex fprice fquant fsales fprofit fq1 fq2 fq3 fq4 fqshare 
    end
end
%need total exports under free trade below 
params.ftotquant = ftotquant;

%compute norms [(distribution) (%chinese exporters) (CHN sales in US) (US sales in CHN)]
tt1 = (factive(1,2)/factive(1,1)-params.match_xshare_chn)/params.match_xshare_chn;  
tt2 = (factive(2,1)/factive(2,2)-params.match_xshare_us)/params.match_xshare_us;
tt3 = (ftotsales(1,2)/sum(ftotsales(:,2))-params.match_cshare)/params.match_cshare;
tt4 = (ftotsales(2,1)/sum(ftotsales(:,1))-params.match_ushare)/params.match_ushare;

nfp6  = sum([spp6(1,2) tt1^2 tt2^2 tt3^2 tt4^2]);
nft6  = sum([stp6(1,2) tt1^2 tt2^2 tt3^2 tt4^2]);

if params.disp==1
    disp(' ');
    disp('  Free Trade Exitflag');         disp(exitflag);
    disp('  Free Trade Price Index');      disp(fP);
    disp('  Free Trade Cutoffs');          disp(fxstar);
    disp('  Free Trade GDP');              disp(fY);   
    disp('  Free Trade Quantity');         disp(ftotquant);
    disp('  Free Trade Sales');            disp(ftotsales);
    disp('  Free Trade Import Q Share');   disp([ftotquant(2,1)/sum(ftotquant(:,1)); ftotquant(1,2)/sum(ftotquant(:,2))]);
    disp('  Free Trade Active Firms');     disp(factive);
    disp('  Free Trade Aggregate Profit'); disp(sum(sum(ftotprofit)))
    disp('  Free Trade Profit Dividend');  disp([fpi, sum(sum(ftotprofit))/200]); 
    disp('  Free Trade Weighted Avg TFP'); disp(fwavgtfp);
    clear P0 a0 P o d ret exitflag
end



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%% EFFICIENT ALLOCATION SOLUTION %%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%initial PC PU price index guess
disp('Solve Efficient Allocation');
P0                     = [0.08; 0.08];    
a0                     = 0.06;


%solve for license price "ea" that matches x2004/x2005 in the data
options = optimset('Display','off','MaxIter',1000,'MaxFunEvals',20000,'TolX',1e-6,'TolFun',1e-6);
func = @(a) efficient(a,P0,params);
[ea,fval,exitflag,output] = fsolve(func,a0,options);

%recover price indexes given license price solution
func = @(P) free(P,ea,params);
options1 = optimset('Display','off','MaxIter',1000,'MaxFunEvals',20000);
[eP,fval,exitflag,output] = fsolve(func,P0,options1); 

%use eP from last block of code to compute stuff we want to know; these variables are preceded by "e" for efficient allocation
eexitflag  = exitflag;
ret        = solve_pi_and_cutoffs(eP,ea,params);
exstar     = reshape(ret(1:end-1),params.N,params.N);
epi        = ret(end);
eY         = params.W(:,1).*params.L.*(1+epi);
tempa      = [0 ea; 0 0];

for o=1:params.N
    for d=1:params.N
        eindex       = params.x>exstar(o,d);
        eprice       = (params.SIG/(params.SIG-1)).*(params.W(o,d)*params.TAU(o,d)./params.x(eindex) + params.W(o,d)*tempa(o,d));
        eq1          = (params.SIG/(params.SIG-1))^(-params.SIG);
        eq2          = ((params.W(o,d)*params.TAU(o,d))./params.x(eindex) + params.W(o,d)*tempa(o,d)).^(-params.SIG);
        eq3          = eP(d)^(params.SIG-1);
        eq4          = params.MU*eY(d);
        equant       = eq1.*eq2.*eq3.*eq4;
        esales       = eprice.*equant;
        eprofit      = equant.*(eprice - (params.W(o,d)*params.TAU(o,d)./params.x(eindex) + params.W(o,d)*tempa(o,d))) - (params.W(o,d)*params.F(o,d));
        eqshare      = equant./sum(equant);

        %find percentiles
        for ppp=[50 75 90 95 99 99.9]
            if ppp==99.9
                sss = ['p' int2str(ppp*10) '=prctile(esales,'       int2str(ppp) ');'];
                eval(sss);
                ttt = ['x' int2str(ppp*10) '=sum(esales(esales<p' int2str(ppp*10) '));'];
                eval(ttt);
                uuu = ['u' int2str(ppp*10) '=x' num2str(ppp*10) '/sum(esales);'];
                eval(uuu);
            else
                sss = ['p' int2str(ppp) '=prctile(esales,'       int2str(ppp) ');'];
                eval(sss);
                ttt = ['x' int2str(ppp) '=sum(esales(esales<p' int2str(ppp) '));'];
                eval(ttt);
                uuu = ['u' int2str(ppp) '=x' num2str(ppp) '/sum(esales);'];
                eval(uuu);
            end                   
        end

        %report distributions to screen if needed
        eu(1:6,o,d) = [u75 u90-u75  u95-u90 u99-u95 u999-u99 1-u999];         
        
        %examine export growth and price change of extensive margin (efficient -> free trade)
        %p and q are computed here like above, but not restricted to the firms above cutoff
        ep              = (params.SIG/(params.SIG-1)).*((params.W(o,d)*params.TAU(o,d))./params.x + params.W(o,d)*ea);
        eq              = (params.SIG/(params.SIG-1))^(-params.SIG).*((params.W(o,d)*params.TAU(o,d))./params.x + params.W(o,d)*ea).^(-params.SIG).*eP(d)^(params.SIG-1).*params.MU*eY(d);
        fp              = (params.SIG/(params.SIG-1)).*((params.W(o,d)*params.TAU(o,d))./params.x + params.W(o,d)*0);
        fq              = (params.SIG/(params.SIG-1))^(-params.SIG).*((params.W(o,d)*params.TAU(o,d))./params.x + params.W(o,d)*0).^(-params.SIG).*fP(d)^(params.SIG-1).*params.MU*fY(d);

        %compute change in firm-level quantity 
        dq              = fq-eq;
        qintensive(o,d) = sum(dq(eindex,:));
               
        %compute market share weighted prices in each year by margin
        findex           = params.x>fxstar(o,d);
        eps(o,d)         = mean(ep(eindex));                                            %avg price 
        fps(o,d)         = mean(fp(findex));                                            %avg price 
        epw(o,d)         = sum((eq(eindex)/sum(eq(eindex))).*ep(eindex));               %wavg price 
        fpw(o,d)         = sum((fq(findex)/sum(fq(findex))).*fp(findex));               %wavg price 
        extensive        = logical(findex - eindex);
        %[sum(findex) sum(eindex) sum(extensive)]
        if sum(extensive)>0
            fpextensive(o,d) = sum((fq(extensive)/sum(fq(extensive))).*fp(extensive));  %part of 2nd wavg price due to entrants        
            epintensive(o,d) = sum((eq(eindex)/sum(eq(eindex))).*ep(eindex));           %part of 1st wavg price due to incumbents
            fpintensive(o,d) = sum((fq(eindex)/sum(fq(eindex))).*fp(eindex));           %part of 2nd wavg price due to incumbents
        end
       
        %catch other variables needed for later
        eactive(o,d)    = length(params.x(eindex));
        etotquant(o,d)  = sum(equant);
        etotsales(o,d)  = sum(esales);
        etotprofit(o,d) = sum(eprofit);

        eavgtfp(o,d)    = mean(params.x(eindex));
        ewavgtfp(o,d)   = sum(eqshare.*params.x(eindex)); 
        
        if o==1 & d==2
            params.eindex12  = eindex;
            params.equant12  = equant;
            params.eqshare12 = eqshare;
        end
        
        clear eindex eprice equant esales eprofit eq1 eq2 eq3 eq4 eqshare ep eq fp fq dq extensive
    end
end
%need total exports under efficient allocation below
params.etotquant = etotquant;



%display results from above
if params.disp==1
    disp(' ');
    disp('  Eff Allocation Exitflag');         disp(eexitflag);
    disp('  Eff Allocation Price Index');      disp(eP);
    disp('  Eff Allocation Cutoffs');          disp(exstar);
    disp('  Eff Allocation GDP');              disp(eY);   
    disp('  Eff Allocation Quantity');         disp(etotquant);
    disp('  Eff Allocation Sales');            disp(etotsales);
    disp('  Eff Allocation Import Q Share');   disp([etotquant(2,1)/sum(etotquant(:,1)); etotquant(1,2)/sum(etotquant(:,2))]);
    disp('  Eff Allocation Active Firms');     disp(eactive);
    disp('  Eff Allocation Aggregate Profit'); disp(sum(sum(etotprofit)))
    disp('  Eff Allocation Profit Dividend');  disp([epi, sum(sum(etotprofit))/200]); 
    disp('  Eff Allocation W Avg TFP');        disp(ewavgtfp);
    clear P0 a0 P o d ret exitflag
end

if 1==0
    %compare eff vs free
    disp('China Price (e,f,f/e)');                disp([eP(1) fP(1) fP(1)/eP(1)]);
    disp('US Price (e,f,f/e)');                   disp([eP(2) fP(2) fP(2)/eP(2)]);
    disp('China-US AVG TFP (e,f,f/e');            disp([eavgtfp(1,2) favgtfp(1,2) favgtfp(1,2)/eavgtfp(1,2)]);    
    disp('China-US WAVG TFP (e,f,f/e');           disp([ewavgtfp(1,2) fwavgtfp(1,2) fwavgtfp(1,2)/ewavgtfp(1,2)]);    
    disp('China-US AVG Export Price (e,f)');      disp([eps(1,2) fps(1,2)]);
    disp('China-US WAVG Export Price (e,f)');     disp([epw(1,2) fpw(1,2)]);
    disp('China-US Inc WAVG Export Price (e,f)'); disp([epintensive(1,2) fpintensive(1,2)]);
    disp('China-US Export Quant (e,f)');          disp([etotquant(1,2) ftotquant(1,2)]);    
    disp('China-US Inc Export Quant Growth');     disp([qintensive(1,2) qintensive(1,2)/(ftotquant(1,2)-etotquant(1,2))]);
    disp('China-US Q Mkt Share of Incumbents');   disp([(etotquant(1,2)+qintensive(1,2))/ftotquant(1,2)]);

    disp('China Imp Pen of US (e,f)');            disp([etotsales(1,2)/sum(etotsales(:,2)) ftotsales(1,2)/sum(ftotsales(:,2))]);
    disp('US Imp Pen of China (e,f)');            disp([etotsales(2,1)/sum(etotsales(:,1)) ftotsales(2,1)/sum(ftotsales(:,1))]);
    disp('Chinese Exporters (e,f)');              disp([eactive(1,2)/eactive(1,1) factive(1,2)/factive(1,1)]);    
    disp('US Exporters (e,f)');                   disp([eactive(2,1)/eactive(2,2) factive(2,1)/factive(2,2)]);   
    disp('Distribution (e,f)');                   disp([eu(:,1,2) fu(:,1,2)]);
end

save lognormal_asym_20120509
%zzz = strcat('C:\Users\pks4\Documents\My Dropbox\research\mfa\matlab4\ln_',num2str(round(params.SD*100)));
%save(zzz);

%end   %tempsd loop






