*** 2012.10.29
*** This file replicates the tables in "Trade Liberalization and Embedded Institutional Reform: Evidence from Chinese Exporters" by Khandelwal, Schott and Wei
*** These files are for replication purposes only.
*** There are two main data files: mfa.dta and mfa_sub.dta
***    - mfa.dta creates Table 1; it contains the all bound and unbound exports to the US, EU and Canada
***    - mfa_sub.dta creates Tables 2-5; it contains only the HS codes that contain both bound and unbound exports to the US, EU and Canada.
*** There are two additional support files: production.dta and party_totexports.dta
***    - production.dta is the 2005 NBS data of textile and apparel (industries 17 and 18) firms that report non-zero exports. It is used to generate Figure 1
***    - party_totexports.data contains the total exports (across all HS codes in the Chinese customs data) for each firm.

*set root folder
global replication ="C:\research\Dropbox\mfa (1)\replication\submitted files\stata"
cd "$replication"


*1   TABLE 1
****************************************************************************************
use mfa,replace
	egen f = tag(party_id gx year)
	gen v000 = value/1000000000
	log using table1.log, replace
		noi table year gx, c(sum v000) format(%9.2f)
		noi table year gx, c(sum f)
	cap log close

	
*2   TABLE 2
****************************************************************************************
use mfa_sub, clear
	rename quantity q
	gen countrycode = ctry
	keep party_id hs8_chn countrycode q gx year o2
	reshape wide q, i(party_id hs8_chn countrycode gx year) j(o2)
	forval o=1/3 {
		replace q`o' = 0 if q`o'==.
		}
	collapse (sum) q1 q2 q3, by(hs8 countrycode gx year)
	g qhc = q1 + q2 + q3
	forval o=1/3 {
		g qms`o' = q`o'/qhc
		}
	gen gx6  = gx==6
	forval y = 2002/2005 {
		reg qms1 gx6 if year==`y'
		est store qs`y'
		}
	noi esttab qs* using table2.csv, cells(b(star fmt(%9.3f)) se(fmt(%9.3f))) starlevel(* .1 ** .05 *** .01) stardetach stats(r2 N, fmt(%9.3g)) style(tab) varwidth(8) modelwidth(8) plain replace
	est clear

*3   TABLE 3
****************************************************************************************
**   section 3.1 prepares the data for table 3. It constructs the margins by ownership type
**   section 3.2 runs the regressions for table 3

*3.1 Prepare data for Table 3
	qui forvalues y=2003/2005 {
		use mfa_sub, clear
		local yy = `y'-1
		gen v  = value/1000000000
		rename quantity q
		gen countrycode = ctry
		keep if year==`y' | year==`yy'
		keep party_id hs8_chn countrycode v q gx year o2
		reshape wide v q, i(party_id hs8_chn countrycode gx o2) j(year)
		sort party
		merge party using party_totexports, keep(totalexports`yy')
			drop if _m==2
			drop _m
		gen prev_exp  = totalexports`yy'~=0

		gen inc       = v`y'~=. & v`yy'~=.
		gen new       = v`y'~=. & v`yy'==. & prev_exp==0
		gen switch    = v`y'~=. & v`yy'==. & prev_exp==1
		gen exit 	  = v`y'==. & v`yy'~=.

		replace v`y'=0 if v`y'==.
		replace v`yy'=0 if v`yy'==.
		replace q`y'=0 if q`y'==.
		replace q`yy'=0 if q`yy'==.

		gen dv        = v`y' - v`yy'
		gen dq        = q`y' - q`yy'

		egen vhc`y'  = total(v`y'), by(hs8 countrycode)
		egen vhc`yy' = total(v`yy'), by(hs8 countrycode)
		egen qhc`y'  = total(q`y'), by(hs8 countrycode)
		egen qhc`yy' = total(q`yy'), by(hs8 countrycode)

		gen iq`y'     = q`y'*inc
		gen iq`yy'    = q`yy'*inc
		egen iqhc`y'  = total(iq`y'), by(hs8 countrycode)
		egen iqhc`yy' = total(iq`yy'), by(hs8 countrycode)
		egen dqt      = total(dq), by(hs8 countrycode)
		gen dqs       = dq/dqt
		gen dqg       = dq/q`yy'

		foreach i in inc new switch exit {
			gen v_`i'_`y'   = v`y'*`i'
			gen v_`i'_`yy'   = v`yy'*`i'

			gen dv_`i'      = dv*`i'
			gen dq_`i'      = dq*`i'
			gen dqs_`i'	= dqs*`i'

			gen sv_`i'_`y'  = (v`y' / vhc`y')*`i'
			gen sv_`i'_`yy' = (v`yy' / vhc`yy')*`i'
			gen sq_`i'_`y'  = (q`y' / qhc`y')*`i'
			gen sq_`i'_`yy' = (q`yy' / qhc`yy')*`i'

			gen siq_`i'_`y'  = (iq`y' / iqhc`y')*`i'
			gen siq_`i'_`yy' = (iq`yy' / iqhc`yy')*`i'

		}

		sum siq*

		gen dv_enter = dv_new + dv_switch + dv_exit
		foreach i in `y' `yy' {
			gen sv`i' = sv_inc_`i'+sv_new_`i'+sv_switch_`i'+sv_exit_`i'
			egen check`i' = total(sv`i'), by(countrycode hs8)
			sum check`i' if check`i' ~=0
		}
		foreach i in inc new switch exit {
		  foreach j in v q {
			replace s`j'_`i'_`y'  = . if check`y'==0
			replace s`j'_`i'_`yy' = . if check`yy'==0
		  }
		}
		sort hs8 country party
		save shares_`y', replace	
	}
	qui forvalues y=2003/2005 {
		use shares_`y', clear
		local yy = `y'-1
		collapse (sum) sv* sq* (mean) gx, by(hs8 countrycode o2)	
		fillin hs8 countrycode o2
		egen t1 = mean(gx), by(hs8 countrycode)
		replace gx = t1 if gx==.
		drop if gx==.
		drop t1

		foreach i in inc new switch exit {
			replace sq_`i'_`y'  = 0 if sq_`i'_`y'==.
			replace sq_`i'_`yy' = 0 if sq_`i'_`yy'==.
		}

		gen t1= sq_inc_`yy' + sq_exit_`yy'
		egen check_`yy' = sum(t1), by(hs8 countrycode)
		sum check_`yy', det
		drop t1

		gen t1= sq_inc_`y' + sq_new_`y' + sq_switch_`y'
		egen check_`y' = sum(t1), by(hs8 countrycode)
		sum check_`y', det
		drop t1

		drop if check_`y'==0 | check_`yy'==0
		drop sv* _f check*
		reshape wide sq*, i(hs8 country gx) j(o2)

		forval o=1/3 {
			g dinc`o'    = sq_inc_`y'`o' - sq_inc_`yy'`o'
			g dnew`o'    = sq_new_`y'`o'
			g dexit`o'   = -sq_exit_`yy'`o'
			g dswitch`o' = sq_switch_`y'`o'
			g dnetentry`o' = dnew`o' + dswitch`o' + dexit`o'
			g doverall`o' = dinc`o' + dnew`o' + dswitch`o' + dexit`o'
			}	
			egen dinc_a    = rsum(sq_inc_`y'*)
			egen dinc_b    = rsum(sq_inc_`yy'*)
			g    dinc      = dinc_a - dinc_b
				drop dinc_a dinc_b
			egen dnew    = rsum(sq_new_`y'*)
			egen dexit   = rsum(sq_exit_`yy'*)
				replace dexit = -dexit
			egen dswitch = rsum(sq_switch_`y'*)
			egen dnetentry = rsum(dnetentry*)
			egen doverall = rsum(doverall*)

		foreach i in inc new switch exit {
			table gx, c(mean d`i' mean d`i'1 mean d`i'2 mean d`i'3)
			}
		drop if gx<5
		g mfauec = gx==6
		save did_`y', replace
		}	

		clear
		forval nn = 2003/2005 {
			use did_`nn', clear
			keep hs8_chn countrycode gx dinc1-mfauec
			gen year=`nn'
			save did_`nn'_long, replace
		}
		use did_2005_long, clear
		append using did_2004_long
		append using did_2003_long

		gen y5    = year==2005
		gen gx6   = gx==6
		gen yg    = y5*gx6
		egen hc   = group(countrycode hs8)

		g nx = dexit + dswitch + dnew
		g tt = dinc + dexit + dswitch + dnew

		forval j=1/3 {
			g nx`j' = dexit`j' + dswitch`j' + dnew`j'
			g tt`j' = dinc`j' + nx`j'
			}
	save qms_reg,replace
	qui forval y=2003/2005 {
		cap erase did_`y'.dta
		cap erase did_`y'_long.dta
		cap erase shares_`y'.dta
		}

*3.2 Run Regressions for Table 3
**   - saves output as xml files
**   - {margin}1 is the indicated margin for SOEs, {margin}2 is the indicated margin for Private firms, {margin}3 is the indicated margin for FIEs
**   - k=1 is the top panel of Table 3, k=4 is the middle panel, k=5 is the right panel
	foreach k of numlist 1 4 5 {
		use qms_reg,clear
			rename countrycode ctry
			egen h8c = group(hs8 ctry)

			g y4  = year==2004
			g y4g = gx6*y4

			global I0 y5 gx6 yg
			global I1 y4 gx6 y4g
		if `k'~=5 {
				if `k'==1 {
					local cond = "$I0 if year>=2004, cluster(hs8)"
					}
				if `k'==4 {
					local cond = "$I1 if year<=2004, cluster(hs8)"
					}
			qui reg dinc `cond'
				est store dinc
			qui foreach x in dinc1 dinc2 dinc3 dexit dexit1 dexit2 dexit3 dswitch dswitch1 dswitch2 dswitch3 dnew dnew1 dnew2 dnew3 nx nx1 nx2 nx3 tt tt1 tt2 tt3 {
				reg `x' `cond'
				est store `x'
				}
			noi esttab * using table3_`k'.csv, cells(b(star fmt(%9.3f)) se(fmt(%9.3f))) starlevel(* .1 ** .05 *** .01) stardetach stats(r2 N, fmt(%9.3g)) style(tab) varwidth(8) modelwidth(8) plain replace
			est clear
			}

		if `k' == 5 {
			qui areg dinc $I0 if year>=2004, a(h8c) cluster(hs8)
				est store dinc
			qui foreach x in dinc1 dinc2 dinc3 dexit dexit1 dexit2 dexit3 dswitch dswitch1 dswitch2 dswitch3 dnew dnew1 dnew2 dnew3 nx nx1 nx2 nx3 tt tt1 tt2 tt3 {
				areg `x' $I0 if year>=2004, a(h8c) cluster(hs8)
				est store `x'
				}
			noi esttab * using table3_`k'.csv, cells(b(star fmt(%9.3f)) se(fmt(%9.3f))) starlevel(* .1 ** .05 *** .01) stardetach stats(r2 N, fmt(%9.3g)) style(tab) varwidth(8) modelwidth(8) plain replace
			est clear
			}
	}
	cap erase qms_reg.dta
	cap est clear

*4   TABLE 4-5
****************************************************************************************
**   section 4.1 constructs the quality measures according to equation 7
**   section 4.2 prepares the data for tables 4-5. it constructs the price and quality-adjusted margins by ownership type
**   section 4.3 runs the regressions for tables 4-5.

*4.1 Construct quality
qui {
use mfa_sub, clear
	keep if year>=2002
	rename quantity q
	rename value v
	drop if q==0
	keep if gx==5|gx==6
	keep party_id hs8_chn ctry v q year gx

	g lq = ln(q)

	g uv = v/q
	g luv = ln(uv)
	egen hct = group(hs8 ctry year)
	egen ct = group(ctry year)
	egen h  = group(hs8)
		compress
	global s = 4

	g lqp = lq + $s*luv

	xi: areg lqp i.ct, a(h)
	predict e,r

	* get quality
	g l = exp(e/($s-1))

	*quality-adjusted price 
	g qap = uv/l

	g qapd = (uv/l)^-1

	foreach v of varlist uv l qap qapd {
		replace `v' = ln(`v')
		}

	drop if uv == .
	drop if l == .
	drop if qap == .
	drop if qapd == .

	rename q qty0
	rename v v0
	keep party_id hs8 ctry year l qap uv qty0 v0 gx
	reshape wide l qap uv qty0 v0, i(gx party_id hs8 ctry) j(year)
	sort party_id hs8 ctry
save lambda,replace
}

*4.2  Prepare data for Tables 4-6
**    -[loop over prices (uv) and quality-adjusted prices (qap)]
local vlist = "uv qap"
	qui foreach tt of local vlist {
		noisily dis [" ++++++++++   `tt'   ++++++++++ "]
		forvalues y=2005(-1)2003 {

			use mfa_sub, clear
			keep party hs8 ctry 
			duplicates drop
			sort party hs8 ctry
			save temp_mfa_fill_`y', replace

			use mfa_sub, clear
			keep if gx==5|gx==6
			local yy= `y'-1
			rename quantity q
			rename value v
			drop if q==0

			keep if year==`y' | year==`yy'
			keep party_id hs8_chn ctry v q gx year o2 

			reshape wide v q, i(party_id hs8_chn ctry gx o2) j(year)
				sort party
				merge party using party_totexports, keep(totalexports`yy')
					drop if _m==2
					drop _m
			*determine firm margins
			gen prev_exp  = totalexports`yy'~=0
			gen inc       = v`y'~=. & v`yy'~=.
			gen new       = v`y'~=. & v`yy'==. & prev_exp==0
			gen switch    = v`y'~=. & v`yy'==. & prev_exp==1
			gen exit      = v`y'==. & v`yy'~=.
			gen enter     = new + switch
			egen qhc`y'   = total(q`y'), by(hs8 ctry)
			egen qhc`yy'  = total(q`yy'), by(hs8 ctry)

			*compute quantity market shares
			foreach z in `y' `yy' {
				gen theta_`z'  = q`z' / qhc`z'
				replace theta_`z' = . if theta_`z'==0 | q`z'==0
			}

			*gen theta_bar
			gen tfhc       = (theta_`y' + theta_`yy')/2
			egen thct_1    = mean(theta_`yy'), by(hs8 ctry)
			gen dtfhct     = theta_`y' - theta_`yy'

			*aggregate quantities
			sort party_id hs8 ctry 
			merge party_id hs8 ctry using lambda, keep(`tt'`y' `tt'`yy')
				drop if _m==2
				drop _m
			foreach z in `y' `yy' {
				gen l1_`z' = theta_`z'  * `tt'`z'
				egen lbar_`z' = total(l1_`z'), by(hs8 ctry)
				replace lbar_`z' = . if lbar_`z'==0
				}
			gen lbarhc    = (lbar_`y' + lbar_`yy')/2
			gen lbarfhc   = (`tt'`y'     + `tt'`yy')/2
			drop l1_*

			*margins
			gen w1a         = tfhc                 * (`tt'`y'    - `tt'`yy')
			gen w1b         = dtfhct               * (lbarfhc - lbarhc)
			gen w2a         = thct_1               * (`tt'`y'    - lbarhc)
			gen w2b         = (theta_`y'-thct_1)   * (`tt'`y'    - lbarhc)
			gen w3a         = thct_1               * (`tt'`yy'   - lbarhc)
			gen w3b         = (theta_`yy'-thct_1)  * (`tt'`yy'   - lbarhc)

			gen w1          = w1a + w1b
			gen w2          = theta_`y'  * (`tt'`y'    - lbarhc)
			gen w3          = theta_`yy' * (`tt'`yy'   - lbarhc)

			replace w2a=. if enter==0
			replace w2b=. if enter==0
			replace w3a=. if exit==0
			replace w3b=. if exit==0
			replace w2=.  if enter==0
			replace w3=.  if exit==0


			foreach z in w1 w2 w3 w1a w1b w2a w2b w3a w3b {
				display ["`z'"]
				egen `z's = total(`z'), by(hs8 ctry)
			}

			gen dl          = w1s + w2s - w3s  
			gen dl_alt      = lbar_`y'- lbar_`yy'
			replace dl=. if dl_alt==.

			*make exits negative
			foreach z in w3 w3a w3b {
				replace `z's = -`z's 
			}

			foreach z in w1 w2 w3 w1a w1b w2a w2b w3a w3b {
				replace `z's = . if lbarhc==.
				gen `z'sp    = `z's
			}


			gen dll     = dl
			gen dl_altl = dl_alt

			egen i = tag(hs8 ctry)

			*merge back in variables that we wanted to put in i() in the reshape command above but which did not fit
			sort party hs8 ctry
			merge party hs8 ctry using temp_mfa_fill_`y'
			tab _merge
			drop if _merge==2
			drop _merge
			compress
			sort hs8 ctry party
			save eq13_`y', replace
		}
	*eq13 dataset for prices by ownership
		clear
		qui forvalues y=2003/2005 {
			use eq13_`y', clear
			local yy = `y'-1

			keep hs8_chn party_id ctry gx o2 w1 w2 w3 w1a w1b w2a w2b w3a w3b inc exit enter lbarhc lbar_`yy' lbar_`y'
			foreach z in w1 w2 w3 w1a w1b w2a w2b w3a w3b  {
				rename `z' `z'_
			}
			reshape wide w1_ w2_ w3_ w1a_ w1b_ w2a_ w2b_ w3a_ w3b_, i(party hs8 ctry gx lbarhc lbar_`y' lbar_`yy') j(o2)

			foreach z in w1 w2 w3 w1a w1b w2a w2b w3a w3b {
				display ["`z'"]
				egen `z's_1 = total(`z'_1), by(hs8 ctry)
				egen `z's_2 = total(`z'_2), by(hs8 ctry)
				egen `z's_3 = total(`z'_3), by(hs8 ctry)
			}

			*make exits negative
			foreach z in w3 w3a w3b {
				replace `z's_1 = -`z's_1 
				replace `z's_2 = -`z's_2 
				replace `z's_3 = -`z's_3 
			}

			foreach z in w1 w2 w3 w1a w1b w2a w2b w3a w3b {
				foreach i in 1 2 3 {
					replace `z's_`i' = . if lbarhc==.
					gen `z's_`i'p = `z's_`i'
				}
			}	
			egen i = tag(hs8 ctry) 
			save eq13_`y'_o2, replace

			*merge back in variables that we wanted to put in i() in the reshape command above but which did not fit
			sort party hs8 ctry
			merge party hs8 ctry using temp_mfa_fill_`y'
			tab _merge
			drop if _merge==2
			drop _merge
			save, replace		
		}

	*4.2.1 Figures 2 and 3
	***************************************
	if "`tt'" == "uv" {
		local k1 = "Prices"
	qui forval y=2005(-1)2004 {
		local yy = `y' - 1
		use eq13_`y', clear
		keep if gx==6 | gx==5
		gen d1`tt'  = .
		gen type = .
		replace type = 1 if inc==1
		replace type = 2 if enter==1
		replace type = 3 if exit==1

		replace d1`tt' = `tt'`y' - lbarhc if type==1 | type==2
		replace d1`tt' = `tt'`yy' - lbarhc if type==3

		*calculate extreme obs from each distribution
		foreach z in 1 99 {
			egen c`z' = pctile(d1`tt'), p(`z') by(gx type)
		}

		label var d1`tt' "Relative Price"
		capture drop cut*
		gen cut  = d1`tt'>c1 & d1`tt'<c99

		sort party hs8 ctry
		twoway (kdensity d1`tt' if cut & gx==6 & type==1, lp(solid) lc(black)  lw(medthick)) (kdensity d1`tt' if cut & gx==6 & type==2, lp(dash) lc(gs5) lw(medthick)) (kdensity d1`tt' if cut & gx==6 & type==3, lp(dot) lc(gs10) lw(medthick)), ytitle("Density") xtitle("Ratio") legend(size(small) rows(1) lab(1 "`y' Incumbents") lab(2 "`y' Entrants") lab(3 "`yy' Exiters")) title("Distribution of `y' Quota-Bound `k1'") subtitle("By Margin") note("First and ninety-ninth percentiles are dropped from each distribution.", span) graphregion(lcolor(white) fcolor(white)) saving(`tt'dist_mfa_cut_`y'.gph,replace)
		twoway (kdensity d1`tt' if cut & gx==5 & type==1, lp(solid) lc(black)  lw(medthick)) (kdensity d1`tt' if cut & gx==5 & type==2, lp(dash) lc(gs5) lw(medthick)) (kdensity d1`tt' if cut & gx==5 & type==3, lp(dot) lc(gs10) lw(medthick)), ytitle("Density") xtitle("Ratio") legend(size(small) rows(1) lab(1 "`y' Incumbents") lab(2 "`y' Entrants") lab(3 "`yy' Exiters")) title("Distribution of `y' Quota-Free `k1'") subtitle("By Margin") note("First and ninety-ninth percentiles are dropped from each distribution.", span) graphregion(lcolor(white) fcolor(white)) saving(`tt'dist_otc_cut_`y'.gph,replace)
		}
		*Save Figures 2/3
		noi graph use uvdist_mfa_cut_2005.gph, name(figure2,replace)
			graph save figure2 figure2,replace
		noi graph use uvdist_mfa_cut_2004.gph, name(figure3a,replace)
			graph save figure3a figure3a,replace
		noi graph use uvdist_otc_cut_2005.gph, name(figure3b,replace)
			graph save figure3b figure3b,replace
			cap erase uvdist_otc_cut_2005.gph
			cap erase uvdist_mfa_cut_2005.gph
			cap erase uvdist_otc_cut_2004.gph
			cap erase uvdist_mfa_cut_2004.gph
	}
	*get trims 
		local y=2005
			use eq13_`y', clear
			keep if i==1
			collapse (mean) dl_altl, by(hs8 ctry gx) fast
			save simple_`y'_01, replace

		local yy=2004
			use eq13_`yy', clear
			keep if i==1
			collapse (mean) dl_altl, by(hs8 ctry gx) fast
			save simple_`yy'_01, replace

		local yyy=2003
			use eq13_`yyy', clear
			keep if i==1
			collapse (mean) dl_altl, by(hs8 ctry gx) fast
			save simple_`yyy'_01, replace

		use simple_2005_01, clear
			gen year=2005
		append using simple_2004_01
			replace year=2004 if year==.
		append using simple_2003_01
			replace year=2003 if year==.
			cap erase simple_2005_01.dta
			cap erase simple_2004_01.dta
			cap erase simple_2003_01.dta
		foreach z in 1 99 {
			egen c`z' = pctile(dl_altl), p(`z') by(gx year)
			}
		gen cut1  = dl_altl>c1 & dl_altl<c99 & dl_altl~=.
		
		sort hs8 ctry year
		gen check = dl_altl
		save hc_cuts_`tt', replace  

	qui forval nn = 2003/2005 {
	use eq13_`nn'_o2, clear
		keep if i
		gen year=`nn'
		sort hs8 ctry year
		merge hs8 ctry year using hc_cuts_uv, keep(cut1)
		tab _merge
		drop if _merge==2
		drop _merge
		*keep if cut1
		foreach z in w1 w2 w3 {
				gen `z'_1p = `z'as_1p + `z'bs_1p
				gen `z'_2p = `z'as_2p + `z'bs_2p
				gen `z'_3p = `z'as_3p + `z'bs_3p
			}
		foreach z in 1 2 3 {
				gen w23s_`z'p = w2s_`z'p + w3s_`z'p
				gen dll_`z' = w1s_`z'p+w2s_`z'p + w3s_`z'p
		}
		keep hs8_chn ctry gx year dll_1 dll_2 dll_3 w1s_1p w1s_2p w1s_3p w2s_1p w2s_2p w2s_3p w3s_1p w3s_2p w3s_3p w23s_1p w23s_2p w23s_3p w1as_1p w1bs_1p w1as_2p w1bs_2p w1as_3p w1bs_3p
	save eq13_`nn'_long, replace
	}

	*append
	use eq13_2005_long, replace
	append using eq13_2004_long
	append using eq13_2003_long

	*get rid of non-uec groups
	keep if gx>=5 & gx~=.
	sort hs8 ctry gx year
	save eq13_long_o2, replace

	qui forval nn=2003/2005 {
	use eq13_`nn', clear
		keep if i
		gen year=`nn'
		sort hs8 ctry year
		merge hs8 ctry year using hc_cuts_uv, keep(cut1)
		tab _merge
		drop if _merge==2
		drop _merge
		*keep if cut1
		gen w23sp = w2sp + w3sp
		keep hs8_chn ctry gx year dl_altl w1sp w1asp w1bsp w2sp w3sp w23sp
	save eq13_`nn'_long_agg, replace
	}

	*append
	use eq13_2005_long_agg, replace
	append using eq13_2004_long_agg
	append using eq13_2003_long_agg

	*get rid of non-uec groups
	keep if gx>=5 & gx~=.
	save eq13_long_agg, replace

	*put above together
	use eq13_long_agg, replace
	sort hs8 ctry gx year
	merge hs8 ctry gx using eq13_long_o2
	tab _merge 
	drop _merge
	save eq13_long, replace
	save eq13_long_`tt',replace


	*prepare files for regressions
	clear
	set matsize 2500
	use eq13_long, clear
		gen y5    = year==2005
		gen gx6   = gx==6
		gen yg    = y5*gx6
		egen hc   = group(ctry hs8)
		egen h    = group(hs8)
		qui tab ctry, g(_ctry)

		*total intensive margin (within + across)
		cap g w1sp = w1asp + w1bsp
		g w1sp_1p = w1as_1p + w1bs_1p
		g w1sp_2p = w1as_2p + w1bs_2p
		g w1sp_3p = w1as_3p + w1bs_3p

		*total extensive margin (within + across)
		cap g w23sp = w2sp + w3sp
		cap g w23s_1p = w2sp_1p + w3sp_1p
		cap g w23s_2p = w2sp_2p + w3sp_2p
		cap g w23s_3p = w2sp_3p + w3sp_3p
	save pricereg_`tt',replace
}	
	*Remove all intermediate files
	qui forval y=2003/2005 {
	local flist = "hc_cuts_l hc_cuts_qap hc_cuts_uv ldist_mfa_cut did did_p eq13_long eq13_long_l eq13 eq13_long_qap eq13_long_uv eq13_long_agg eq13_long_o2 eq13_long_o2 eq_long_qap eq_long_uv temp_mfa_fill temp_mfa_fill_2005.dta eq13_2005.dta eq13_2005_o2.dta simple_2005_01.dta eq13_2005_long.dta eq13_2005_long_agg.dta eq13_2005_long_agg.dta eq13_2005_long_agg.dta temp_mfa_fill_2005.dta eq13_2005.dta eq13_2005_o2.dta simple_2005_01.dta eq13_2004_long.dta temp_mfa_fill_2004.dta eq13_2004.dta eq13_2004_o2.dta simple_2004_01.dta eq13_2004_long.dta eq13_2004_long_agg.dta eq13_2004_long_agg.dta eq13_2004_long_agg.dta temp_mfa_fill_2004.dta eq13_2004.dta eq13_2004_o2.dta simple_2004_01.dta eq13_2003_long.dta temp_mfa_fill_2003.dta eq13_2003.dta eq13_2003_o2.dta simple_2003_01.dta eq13_2003_long.dta eq13_2003_long_agg.dta eq13_2003_long_agg.dta eq13_2003_long_agg.dta temp_mfa_fill_2003.dta eq13_2003.dta eq13_2003_o2.dta simple_2003_01.dta eq13_long.dta eq13_long_o2.dta eq13_long_o2.dta eq13_long.dta eq13_long_agg.dta"
	foreach ff of local flist {
		cap erase lambda.dta
		cap erase `ff'.dta
		cap erase `ff'_`y'.dta
		cap erase `ff'_`y'.gph
		cap erase did_`y'_long.dta
		cap erase did_`y'_o2.dta
		cap erase did_`y'_o2_long.dta
		cap erase did_`y'_long_agg.dta
		cap erase did_p_`y'_long.dta
		cap erase eq13_`y'_long.dta
		cap erase eq13_`y'_o2.dta
		cap erase eq13_`y'_o2_long.dta
		cap erase eq13_`y'_long_agg.dta
		}
	}

*4.3 Run regressions for Tables 4-5
**   - saves output as xml files
**   - {margin}1 is the indicated margin for SOEs, {margin}2 is the indicated margin for Private firms, {margin}3 is the indicated margin for FIEs
**   - k=1 is the top panel of Table 4/5, k=4 is the middle panel, k=5 is the bottom panel
	local vlist = "uv qap"
	qui foreach tt of local vlist {
		noi dis "`tt'"
		if "`tt'"=="uv" {
			local j = 4
			}
		if "`tt'"=="qap" {
			local j = 5
			}
	qui foreach k of numlist 1 4 5 {
		use pricereg_`tt',clear
			egen h8c = group(hs8 ctry)
			sort hs8
			tsset h8c year
			g y4  = year==2004
			g y4g = gx6*y4

			global I0 y5 gx6 yg
			global I1 y4 gx6 y4g
			if `k'~= 5 {
				if `k'==1 {
					local cond = "$I0 if year>=2004, cluster(hs8)"
					}
				if `k'==4 {
					local cond = "$I1 if year<=2004, cluster(hs8)"
					}
			reg dl_altl `cond'
			est store dl_altl
			foreach x in dll_1 dll_2 dll_3 w1asp w1as_1p w1as_2p w1as_3p w1bsp w1bs_1p w1bs_2p w1bs_3p w2sp w2s_1p w2s_2p w2s_3p w3sp w3s_1p w3s_2p w3s_3p w1sp w1sp_1p w1sp_2p w1sp_3p w23sp w23s_1p w23s_2p w23s_3p {
				reg `x' `cond'
				est store `x'
				}
			noi esttab * using table`j'_`k'.csv, cells(b(star fmt(%9.3f)) se(fmt(%9.3f))) starlevel(* .1 ** .05 *** .01) stardetach stats(r2 N, fmt(%9.3g)) style(tab) varwidth(8) modelwidth(8) plain replace
			est clear
			}
		if `k' == 5 {
			areg dl_altl y5 gx6 yg if year>=2004, a(h8c) cluster(hs8)
			est store dl_altl
			foreach x in dll_1 dll_2 dll_3 w1asp w1as_1p w1as_2p w1as_3p w1bsp w1bs_1p w1bs_2p w1bs_3p w2sp w2s_1p w2s_2p w2s_3p w3sp w3s_1p w3s_2p w3s_3p w1sp w1sp_1p w1sp_2p w1sp_3p w23sp w23s_1p w23s_2p w23s_3p {
				areg `x' y5 gx6 yg if year>=2004, a(h8c) cluster(hs8)
				est store `x'
				}
			noi esttab * using table`j'_`k'.csv, cells(b(star fmt(%9.3f)) se(fmt(%9.3f))) starlevel(* .1 ** .05 *** .01) stardetach stats(r2 N, fmt(%9.3g)) style(tab) varwidth(8) modelwidth(8) plain replace
			est clear
			}
		}
	cap erase pricereg_`tt'.dta
	}

	
*5: FIGURE 1
****************************************************************************************
use production,clear
	foreach v of varlist tfp {
		replace `v' = . if `v'<0
		bys o2 year: egen p1 = pctile(`v'), p(1)
		bys o2 year: egen p99 = pctile(`v'), p(99)
			replace `v' = . if `v'<=p1|`v'>=p99
			drop p1 p99
			}
		rename tfp tfpr 
		reshape wide tfpr ix, i(frdm_id o2 tc) j(year)
	*Figure 1
		local k = "2005 TFP, Textile & Clothing Exporters"
		twoway (kdensity tfpr2005 if ix2005==1 & o2==1 & tc==1, xscale(log) xlabel(0.125 .25 .5 1 2 4 8 16 32) lp(solid) lc(black) lw(medthick)) (kdensity tfpr2005 if ix2005==1 & o2==2 & tc==1, xscale(log) xlabel(0.125 .25 .5 1 2 4 8 16 32) lp(dash) lc(gs5) lw(medthick)) (kdensity tfpr2005 if ix2005==1 & o2==3 & tc==1, xscale(log) xlabel(0.125 .25 .5 1 2 4 8 16 32) lp(dash) lc(gs10) lw(medthick)), title("`y' `k'") legend(size(small) rows(1) lab(1 "SOE") lab(2 "Domestic") lab(3 "Foreign")) subtitle("by Ownership") note("First and ninety-ninth percentiles are dropped from each distribution. Collective firms are excluded.",span) ytitle("Density") xtitle("TFP") graphregion(lcolor(white) fcolor(white)) nodraw saving(figure1,replace) 

